searchData={"items":[{"type":"module","title":"SFTPClient","doc":"This is an SFTP Client that wraps Erlang's `:ssh` and `:ssh_sftp` libraries\nfor easier usage in Elixir.","ref":"SFTPClient.html"},{"type":"module","title":"Connect & Disconnect - SFTPClient","doc":"To open a new connection to an SFTP server:\n\n    iex> {:ok, conn} = SFTPClient.connect(host: \"ftp.myhost.com\")\n    {:ok, %SFTPClient.Conn{}}\n\nRefer to the docs for `SFTPClient.Operations.Connect.connect/1` to find out\nall available options.\n\nIt is strongly recommended to close a connection after your operations have\ncompleted:\n\n    iex> SFTPClient.disconnect(conn)\n    :ok\n\nFor short-lived connections you can also use a function as second argument.\nAfter the function body has run or raises, the connection is automatically\nclosed.\n\n    iex> SFTPClient.connect([host: \"ftp.myhost.com\"], fn conn ->\n    ...>   # Do something with conn\n    ...>   \"my result\"\n    ...> end)\n    {:ok, \"my result\"}","ref":"SFTPClient.html#module-connect-disconnect"},{"type":"module","title":"Download - SFTPClient","doc":"You can download a file from the server you can use the following function.\n\n    iex> SFTPClient.download_file(conn, \"my/remote/dir/file.jpg\", \"my/dir/local-file.jpg\")\n    {:ok, \"my/dir/local-file.jpg\"}\n\nWhen the third argument is an existing directory on your file system, the file\nis downloaded to a file with the same name as the one on the server.\n\n    iex> SFTPClient.download_file(conn, \"my/remote/dir/image.png\", \"my/local/dir\")\n    {:ok, \"my/local/dir/image.png\"}\n\nIt is also possible to use Streams to download data into a file or memory.\n\n    iex> SFTPClient.stream_file!(conn, \"my/remote/file.jpg\")\n    ...> |> Stream.into(File.stream!(\"my/local/file.jpg\"))\n    ...> |> Stream.run()\n    :ok","ref":"SFTPClient.html#module-download"},{"type":"module","title":"Upload - SFTPClient","doc":"To upload are file from the file system you can use the following function.\n\n    iex> SFTPClient.upload_file(conn, \"my/local/dir/file.jpg\", \"my/remote/dir/file.jpg\")\n    {:ok, \"my/remote/dir/file.jpg\"}\n\nYou can also use Streams to upload data. Please make sure to set a proper\nchunk size or the upload may be slow.\n\n    iex> File.stream!(\"my/local/file.jpg\")\n    ...> |> Stream.into(SFTPClient.stream_file!(conn, \"my/remote/file.jpg\"))\n    ...> |> Stream.run()\n    :ok","ref":"SFTPClient.html#module-upload"},{"type":"module","title":"List Directory - SFTPClient","doc":"iex> SFTPClient.list_dir(conn, \"my/dir\")\n    {:ok, [\"my/dir/file_1.jpg\", \"my/dir/file_2.jpg\"]}","ref":"SFTPClient.html#module-list-directory"},{"type":"module","title":"Create Directory - SFTPClient","doc":"iex> SFTPClient.make_dir(conn, \"my/new/dir\")\n    :ok\n\nNote that this operation fails unless the parent directory exists.","ref":"SFTPClient.html#module-create-directory"},{"type":"module","title":"Delete - SFTPClient","doc":"To delete a file:\n\n    iex> SFTPClient.delete_file(conn, \"my/remote/file.jpg\")\n    :ok\n\nTo delete a directory:\n\n    iex> SFTPClient.delete_dir(conn, \"my/remote/dir\")\n    :ok\n\nNote that a directory cannot be deleted as long as it still contains files.","ref":"SFTPClient.html#module-delete"},{"type":"module","title":"Rename - SFTPClient","doc":"To move/rename a file or directory:\n\n    iex> SFTPClient.rename(conn, \"my/remote/file.jpg\", \"my/remote/new-file.jpg\")\n    :ok","ref":"SFTPClient.html#module-rename"},{"type":"module","title":"File Info - SFTPClient","doc":"You can retrieve meta data about a file from the server such as file size,\nmodification time, file permissions, owner and so on.\n\n    iex> SFTPClient.file_info(conn, \"my/remote/file.jpg\")\n    {:ok, %File.Stat{}}\n\nRefer to the [`File.Stat`](https://hexdocs.pm/elixir/File.Stat.html) docs for a\nlist of available file information.","ref":"SFTPClient.html#module-file-info"},{"type":"module","title":"Symbolic Links - SFTPClient","doc":"There are also a couple of functions that handle symbolic links.\n\nIt is possible to get the target of a symlink.\n\n    iex> SFTPClient.read_link(conn, \"my/remote/link.jpg\")\n    {:ok, \"my/remote/file.jpg\"}\n\nYou can retrieve meta data about symlinks, similar to `file_info/2`.\n\n    iex> SFTPClient.link_info(conn, \"my/remote/link.jpg\")\n    {:ok, %File.Stat{}}\n\nAnd you are able to create symlinks.\n\n    iex> SFTPClient.make_link(conn, \"my/remote/link.jpg\", \"my/remote/file.jpg\")\n    :ok","ref":"SFTPClient.html#module-symbolic-links"},{"type":"function","title":"SFTPClient.close_handle/1","doc":"","ref":"SFTPClient.html#close_handle/1"},{"type":"function","title":"SFTPClient.close_handle!/1","doc":"","ref":"SFTPClient.html#close_handle!/1"},{"type":"function","title":"SFTPClient.connect/1","doc":"","ref":"SFTPClient.html#connect/1"},{"type":"function","title":"SFTPClient.connect/2","doc":"","ref":"SFTPClient.html#connect/2"},{"type":"function","title":"SFTPClient.connect!/1","doc":"","ref":"SFTPClient.html#connect!/1"},{"type":"function","title":"SFTPClient.connect!/2","doc":"","ref":"SFTPClient.html#connect!/2"},{"type":"function","title":"SFTPClient.delete_dir/2","doc":"","ref":"SFTPClient.html#delete_dir/2"},{"type":"function","title":"SFTPClient.delete_dir!/2","doc":"","ref":"SFTPClient.html#delete_dir!/2"},{"type":"function","title":"SFTPClient.delete_file/2","doc":"","ref":"SFTPClient.html#delete_file/2"},{"type":"function","title":"SFTPClient.delete_file!/2","doc":"","ref":"SFTPClient.html#delete_file!/2"},{"type":"function","title":"SFTPClient.disconnect/1","doc":"","ref":"SFTPClient.html#disconnect/1"},{"type":"function","title":"SFTPClient.download_file/3","doc":"","ref":"SFTPClient.html#download_file/3"},{"type":"function","title":"SFTPClient.download_file!/3","doc":"","ref":"SFTPClient.html#download_file!/3"},{"type":"function","title":"SFTPClient.file_info/2","doc":"","ref":"SFTPClient.html#file_info/2"},{"type":"function","title":"SFTPClient.file_info!/2","doc":"","ref":"SFTPClient.html#file_info!/2"},{"type":"function","title":"SFTPClient.link_info/2","doc":"","ref":"SFTPClient.html#link_info/2"},{"type":"function","title":"SFTPClient.link_info!/2","doc":"","ref":"SFTPClient.html#link_info!/2"},{"type":"function","title":"SFTPClient.list_dir/2","doc":"","ref":"SFTPClient.html#list_dir/2"},{"type":"function","title":"SFTPClient.list_dir!/2","doc":"","ref":"SFTPClient.html#list_dir!/2"},{"type":"function","title":"SFTPClient.make_dir/2","doc":"","ref":"SFTPClient.html#make_dir/2"},{"type":"function","title":"SFTPClient.make_dir!/2","doc":"","ref":"SFTPClient.html#make_dir!/2"},{"type":"function","title":"SFTPClient.make_link/3","doc":"","ref":"SFTPClient.html#make_link/3"},{"type":"function","title":"SFTPClient.make_link!/3","doc":"","ref":"SFTPClient.html#make_link!/3"},{"type":"function","title":"SFTPClient.open_dir/2","doc":"","ref":"SFTPClient.html#open_dir/2"},{"type":"function","title":"SFTPClient.open_dir/3","doc":"","ref":"SFTPClient.html#open_dir/3"},{"type":"function","title":"SFTPClient.open_dir!/2","doc":"","ref":"SFTPClient.html#open_dir!/2"},{"type":"function","title":"SFTPClient.open_dir!/3","doc":"","ref":"SFTPClient.html#open_dir!/3"},{"type":"function","title":"SFTPClient.open_file/3","doc":"","ref":"SFTPClient.html#open_file/3"},{"type":"function","title":"SFTPClient.open_file/4","doc":"","ref":"SFTPClient.html#open_file/4"},{"type":"function","title":"SFTPClient.open_file!/3","doc":"","ref":"SFTPClient.html#open_file!/3"},{"type":"function","title":"SFTPClient.open_file!/4","doc":"","ref":"SFTPClient.html#open_file!/4"},{"type":"function","title":"SFTPClient.read_dir/1","doc":"","ref":"SFTPClient.html#read_dir/1"},{"type":"function","title":"SFTPClient.read_dir!/1","doc":"","ref":"SFTPClient.html#read_dir!/1"},{"type":"function","title":"SFTPClient.read_file/2","doc":"","ref":"SFTPClient.html#read_file/2"},{"type":"function","title":"SFTPClient.read_file!/2","doc":"","ref":"SFTPClient.html#read_file!/2"},{"type":"function","title":"SFTPClient.read_file_chunk/2","doc":"","ref":"SFTPClient.html#read_file_chunk/2"},{"type":"function","title":"SFTPClient.read_file_chunk!/2","doc":"","ref":"SFTPClient.html#read_file_chunk!/2"},{"type":"function","title":"SFTPClient.read_link/2","doc":"","ref":"SFTPClient.html#read_link/2"},{"type":"function","title":"SFTPClient.read_link!/2","doc":"","ref":"SFTPClient.html#read_link!/2"},{"type":"function","title":"SFTPClient.rename/3","doc":"","ref":"SFTPClient.html#rename/3"},{"type":"function","title":"SFTPClient.rename!/3","doc":"","ref":"SFTPClient.html#rename!/3"},{"type":"function","title":"SFTPClient.stream_file/2","doc":"","ref":"SFTPClient.html#stream_file/2"},{"type":"function","title":"SFTPClient.stream_file/3","doc":"","ref":"SFTPClient.html#stream_file/3"},{"type":"function","title":"SFTPClient.stream_file!/2","doc":"","ref":"SFTPClient.html#stream_file!/2"},{"type":"function","title":"SFTPClient.stream_file!/3","doc":"","ref":"SFTPClient.html#stream_file!/3"},{"type":"function","title":"SFTPClient.upload_file/3","doc":"","ref":"SFTPClient.html#upload_file/3"},{"type":"function","title":"SFTPClient.upload_file!/3","doc":"","ref":"SFTPClient.html#upload_file!/3"},{"type":"function","title":"SFTPClient.write_file/3","doc":"","ref":"SFTPClient.html#write_file/3"},{"type":"function","title":"SFTPClient.write_file!/3","doc":"","ref":"SFTPClient.html#write_file!/3"},{"type":"function","title":"SFTPClient.write_file_chunk/2","doc":"","ref":"SFTPClient.html#write_file_chunk/2"},{"type":"function","title":"SFTPClient.write_file_chunk!/2","doc":"","ref":"SFTPClient.html#write_file_chunk!/2"},{"type":"type","title":"SFTPClient.access_mode/0","doc":"File access modes that can be used when opening files directly from the remote\nserver.","ref":"SFTPClient.html#t:access_mode/0"},{"type":"type","title":"SFTPClient.error/0","doc":"A type incorporating all error types.","ref":"SFTPClient.html#t:error/0"},{"type":"module","title":"SFTPClient.Config","doc":"A module containing the connection configuration.","ref":"SFTPClient.Config.html"},{"type":"function","title":"SFTPClient.Config.new/1","doc":"Builds a config from the given `SFTPClient.Config` struct, keyword list or\nmap.","ref":"SFTPClient.Config.html#new/1"},{"type":"type","title":"SFTPClient.Config.t/0","doc":"","ref":"SFTPClient.Config.html#t:t/0"},{"type":"module","title":"SFTPClient.Conn","doc":"A struct containing connection-specific information.","ref":"SFTPClient.Conn.html"},{"type":"type","title":"SFTPClient.Conn.t/0","doc":"","ref":"SFTPClient.Conn.html#t:t/0"},{"type":"module","title":"SFTPClient.Entry","doc":"A struct that represents a directory entry on a remote server, containing the\nfilename, full path and meta data.","ref":"SFTPClient.Entry.html"},{"type":"type","title":"SFTPClient.Entry.t/0","doc":"","ref":"SFTPClient.Entry.html#t:t/0"},{"type":"module","title":"SFTPClient.Handle","doc":"A struct that contains a connection and handle ID that points to a file or\ndirectory on the remote server.","ref":"SFTPClient.Handle.html"},{"type":"type","title":"SFTPClient.Handle.t/0","doc":"","ref":"SFTPClient.Handle.html#t:t/0"},{"type":"module","title":"SFTPClient.KeyProvider","doc":"A provider that loads keys for authentication from the given location.\nImplements the `:ssh_client_key_api` behavior.","ref":"SFTPClient.KeyProvider.html"},{"type":"module","title":"SFTPClient.Operations.UploadFile","doc":"A module that provides functions to upload files to an SFTP server.","ref":"SFTPClient.Operations.UploadFile.html"},{"type":"function","title":"SFTPClient.Operations.UploadFile.upload_file/3","doc":"Uploads a file from the file system to the server.","ref":"SFTPClient.Operations.UploadFile.html#upload_file/3"},{"type":"function","title":"SFTPClient.Operations.UploadFile.upload_file!/3","doc":"Uploads a file from the file system to the server. Raises when the operation\nfails.","ref":"SFTPClient.Operations.UploadFile.html#upload_file!/3"},{"type":"module","title":"SFTPClient.SSHXferAttr","doc":"A struct that contains file and directory meta data.","ref":"SFTPClient.SSHXferAttr.html"},{"type":"function","title":"SFTPClient.SSHXferAttr.from_record/1","doc":"Converts a record of the `:ssh_xfer_attr` type into this struct.","ref":"SFTPClient.SSHXferAttr.html#from_record/1"},{"type":"type","title":"SFTPClient.SSHXferAttr.t/0","doc":"","ref":"SFTPClient.SSHXferAttr.html#t:t/0"},{"type":"module","title":"SFTPClient.Stream","doc":"A stream pointing to a file on an SFTP server. Implements the `Enumerable` and\n`Collectable` protocols.","ref":"SFTPClient.Stream.html"},{"type":"function","title":"SFTPClient.Stream.readable_stream/1","doc":"Gets a stream that reads a file from the remote server in chunks.","ref":"SFTPClient.Stream.html#readable_stream/1"},{"type":"type","title":"SFTPClient.Stream.t/0","doc":"","ref":"SFTPClient.Stream.html#t:t/0"},{"type":"behaviour","title":"SFTPClient.Adapter.SFTP","doc":"A behavior that defines required callbacks for a low-level SFTP adapter.","ref":"SFTPClient.Adapter.SFTP.html"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.close/3","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:close/3"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.del_dir/3","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:del_dir/3"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.delete/3","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:delete/3"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.list_dir/3","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:list_dir/3"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.make_dir/3","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:make_dir/3"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.make_link/4","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:make_link/4"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.open/4","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:open/4"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.opendir/3","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:opendir/3"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.read/4","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:read/4"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.read_file/3","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:read_file/3"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.read_file_info/3","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:read_file_info/3"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.read_link/3","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:read_link/3"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.read_link_info/3","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:read_link_info/3"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.readdir/3","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:readdir/3"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.rename/4","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:rename/4"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.start_channel/3","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:start_channel/3"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.stop_channel/1","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:stop_channel/1"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.write/4","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:write/4"},{"type":"callback","title":"SFTPClient.Adapter.SFTP.write_file/4","doc":"","ref":"SFTPClient.Adapter.SFTP.html#c:write_file/4"},{"type":"behaviour","title":"SFTPClient.Adapter.SSH","doc":"A behavior that defines required callbacks for a low-level SSH adapter.","ref":"SFTPClient.Adapter.SSH.html"},{"type":"callback","title":"SFTPClient.Adapter.SSH.close/1","doc":"","ref":"SFTPClient.Adapter.SSH.html#c:close/1"},{"type":"module","title":"SFTPClient.Operations.CloseHandle","doc":"A module that provides functions to close an open handle pointing to a file or\ndirectory on the SFTP server.","ref":"SFTPClient.Operations.CloseHandle.html"},{"type":"function","title":"SFTPClient.Operations.CloseHandle.close_handle/1","doc":"Closes a handle to an open file or directory on the server.","ref":"SFTPClient.Operations.CloseHandle.html#close_handle/1"},{"type":"function","title":"SFTPClient.Operations.CloseHandle.close_handle!/1","doc":"Closes a handle to an open file or directory on the server. Raises when the\noperation fails.","ref":"SFTPClient.Operations.CloseHandle.html#close_handle!/1"},{"type":"module","title":"SFTPClient.Operations.Connect","doc":"A module containing operations to connect to an SSH/SFTP server.","ref":"SFTPClient.Operations.Connect.html"},{"type":"function","title":"SFTPClient.Operations.Connect.connect/1","doc":"Connects to an SSH server and opens an SFTP channel.","ref":"SFTPClient.Operations.Connect.html#connect/1"},{"type":"function","title":"Options - SFTPClient.Operations.Connect.connect/1","doc":"* `:host` (required) - The host of the SFTP server.\n* `:port` - The port of the SFTP server, defaults to 22.\n* `:user` - The user to authenticate as, when omitted tries to determine the\n  current user.\n* `:password` - The password for the user.\n* `:user_dir` - The directory to read private keys from.\n* `:dsa_pass_phrase` - The passphrase for an DSA private key from the\n  specified user dir.\n* `:rsa_pass_phrase` - The passphrase for an RSA private key from the\n  specified user dir.\n* `:ecdsa_pass_phrase` - The passphrase for an ECDSA private key from the\n  specified user dir.\n* `:private_key_path` - The path to the private key to use for authentication.\n* `:private_key_pass_phrase` - The passphrase that is used to decrypt the\n  specified private key.\n* `:inet` - The IP version to use, either `:inet` (default) or `:inet6`.\n* `:sftp_vsn` - The SFTP version to be used.\n* `:connect_timeout` - The connection timeout in milliseconds (defaults to\n  5000 ms), can be set to `:infinity` to disable timeout.\n* `:operation_timeout` - The operation timeout in milliseconds (defaults to\n  5000 ms), can be set to `:infinity` to disable timeout.\n* `:key_cb` - A 2-item tuple containing:\n   - A module that implements `:ssh_client_key_api` behaviour.\n   - `:ssh_client_key_api` behaviour opts.\n* `:modify_algorithms` - An option passed to the underlying Erlang SSH\n  implementation to support non-OTP default encryption algorithms. To\n  re-enable `diffie-hellman-group1-sha1`, removed in OTP 23, pass:\n  `modify_algorithms: [append: [kex: [:\"diffie-hellman-group1-sha1\"]]]`","ref":"SFTPClient.Operations.Connect.html#connect/1-options"},{"type":"function","title":"SFTPClient.Operations.Connect.connect/2","doc":"Connects to an SSH server and opens an SFTP channel, then runs the function\nand closes the connection when finished. Accepts the same options as\n`connect/1`.","ref":"SFTPClient.Operations.Connect.html#connect/2"},{"type":"function","title":"SFTPClient.Operations.Connect.connect!/1","doc":"Connects to an SSH server and opens an SFTP channel. Accepts the same options\nas `connect/1`. Raises when the connection fails.","ref":"SFTPClient.Operations.Connect.html#connect!/1"},{"type":"function","title":"SFTPClient.Operations.Connect.connect!/2","doc":"Connects to an SSH server and opens an SFTP channel, then runs the function\nand closes the connection when finished. Accepts the same options as\n`connect/1`. Raises when the connection fails.","ref":"SFTPClient.Operations.Connect.html#connect!/2"},{"type":"module","title":"SFTPClient.Operations.DeleteDir","doc":"A module containing operations to delete a directory from the remote server.","ref":"SFTPClient.Operations.DeleteDir.html"},{"type":"function","title":"SFTPClient.Operations.DeleteDir.delete_dir/2","doc":"Deletes the directory specified by path.","ref":"SFTPClient.Operations.DeleteDir.html#delete_dir/2"},{"type":"function","title":"SFTPClient.Operations.DeleteDir.delete_dir!/2","doc":"Deletes the directory specified by path. Raises when the operation fails.","ref":"SFTPClient.Operations.DeleteDir.html#delete_dir!/2"},{"type":"module","title":"SFTPClient.Operations.DeleteFile","doc":"A module containing operations to delete a file from the remote server.","ref":"SFTPClient.Operations.DeleteFile.html"},{"type":"function","title":"SFTPClient.Operations.DeleteFile.delete_file/2","doc":"Deletes the file specified by path.","ref":"SFTPClient.Operations.DeleteFile.html#delete_file/2"},{"type":"function","title":"SFTPClient.Operations.DeleteFile.delete_file!/2","doc":"Deletes the file specified by path. Raises when the operation fails.","ref":"SFTPClient.Operations.DeleteFile.html#delete_file!/2"},{"type":"module","title":"SFTPClient.Operations.Disconnect","doc":"A module containing operations to disconnect from an SSH/SFTP server.","ref":"SFTPClient.Operations.Disconnect.html"},{"type":"function","title":"SFTPClient.Operations.Disconnect.disconnect/1","doc":"Stops an SFTP channel and closes the SSH connection.","ref":"SFTPClient.Operations.Disconnect.html#disconnect/1"},{"type":"module","title":"SFTPClient.Operations.DownloadFile","doc":"A module that provides functions to download files from an SFTP server.","ref":"SFTPClient.Operations.DownloadFile.html"},{"type":"function","title":"SFTPClient.Operations.DownloadFile.download_file/3","doc":"Downloads a file from the remote path and stores it in the given local path.\nWhen the local path is a directory, the file name of the local file is\ninferred from the remote path.","ref":"SFTPClient.Operations.DownloadFile.html#download_file/3"},{"type":"function","title":"SFTPClient.Operations.DownloadFile.download_file!/3","doc":"Downloads a file from the remote path and stores it in the given local path.\nWhen the local path is a directory, the file name of the local file is\ninferred from the remote path. Raises when the operation fails.","ref":"SFTPClient.Operations.DownloadFile.html#download_file!/3"},{"type":"module","title":"SFTPClient.Operations.FileInfo","doc":"A module that provides functions to retrieve information on files and\ndirectories from an SFTP server.","ref":"SFTPClient.Operations.FileInfo.html"},{"type":"function","title":"SFTPClient.Operations.FileInfo.file_info/2","doc":"Returns a `File.Stat` struct from the remote file system object specified by\npath.","ref":"SFTPClient.Operations.FileInfo.html#file_info/2"},{"type":"function","title":"SFTPClient.Operations.FileInfo.file_info!/2","doc":"Returns a `File.Stat` struct from the remote file system object specified by\npath. Raises when the operation fails.","ref":"SFTPClient.Operations.FileInfo.html#file_info!/2"},{"type":"module","title":"SFTPClient.Operations.LinkInfo","doc":"A module that provides functions to retrieve information on symbolic links\nfrom an SFTP server.","ref":"SFTPClient.Operations.LinkInfo.html"},{"type":"function","title":"SFTPClient.Operations.LinkInfo.link_info/2","doc":"Returns a `File.Stat` struct from the remote symbolic link object specified by\npath.","ref":"SFTPClient.Operations.LinkInfo.html#link_info/2"},{"type":"function","title":"SFTPClient.Operations.LinkInfo.link_info!/2","doc":"Returns a `File.Stat` struct from the remote symbolic link object specified by\npath. Raises when the operation fails.","ref":"SFTPClient.Operations.LinkInfo.html#link_info!/2"},{"type":"module","title":"SFTPClient.Operations.ListDir","doc":"A module that provides functions to retrieve a list of files in the given\ndirectory from an SFTP server.","ref":"SFTPClient.Operations.ListDir.html"},{"type":"function","title":"SFTPClient.Operations.ListDir.list_dir/2","doc":"Lists the given directory on the server, returning the filenames as a list of\nstrings.","ref":"SFTPClient.Operations.ListDir.html#list_dir/2"},{"type":"function","title":"SFTPClient.Operations.ListDir.list_dir!/2","doc":"Lists the given directory on the server, returning the filenames as a list of\nstrings. Raises when the operation fails.","ref":"SFTPClient.Operations.ListDir.html#list_dir!/2"},{"type":"module","title":"SFTPClient.Operations.MakeDir","doc":"A module that provides functions to create directories on an SFTP server.","ref":"SFTPClient.Operations.MakeDir.html"},{"type":"function","title":"SFTPClient.Operations.MakeDir.make_dir/2","doc":"Creates a directory specified by path. The path must be a full path to a new\ndirectory. The directory can only be created in an existing directory.","ref":"SFTPClient.Operations.MakeDir.html#make_dir/2"},{"type":"function","title":"SFTPClient.Operations.MakeDir.make_dir!/2","doc":"Creates a directory specified by path. The path must be a full path to a new\ndirectory. The directory can only be created in an existing directory. Raises\nwhen the operation fails.","ref":"SFTPClient.Operations.MakeDir.html#make_dir!/2"},{"type":"module","title":"SFTPClient.Operations.MakeLink","doc":"A module that provides functions to create symlinks on an SFTP server.","ref":"SFTPClient.Operations.MakeLink.html"},{"type":"function","title":"SFTPClient.Operations.MakeLink.make_link/3","doc":"Creates a symbolic link pointing to `target_path` with the name\n`symlink_path`.","ref":"SFTPClient.Operations.MakeLink.html#make_link/3"},{"type":"function","title":"SFTPClient.Operations.MakeLink.make_link!/3","doc":"Creates a symbolic link pointing to `target_path` with the name\n`symlink_path`. Raises when the operation fails.","ref":"SFTPClient.Operations.MakeLink.html#make_link!/3"},{"type":"module","title":"SFTPClient.Operations.OpenDir","doc":"A module that provides functions to open a directory on an SFTP server in\norder to list their contents.","ref":"SFTPClient.Operations.OpenDir.html"},{"type":"function","title":"SFTPClient.Operations.OpenDir.open_dir/2","doc":"Opens a handle to a directory on the server. The handle can be used for\nreading directory contents.","ref":"SFTPClient.Operations.OpenDir.html#open_dir/2"},{"type":"function","title":"SFTPClient.Operations.OpenDir.open_dir/3","doc":"Opens a handle to a directory on the server. The handle can be used for\nreading directory contents. Then runs the function and closes the handle when\nfinished.","ref":"SFTPClient.Operations.OpenDir.html#open_dir/3"},{"type":"function","title":"SFTPClient.Operations.OpenDir.open_dir!/2","doc":"Opens a handle to a directory on the server. The handle can be used for\nreading directory contents. Raises when the operation fails.","ref":"SFTPClient.Operations.OpenDir.html#open_dir!/2"},{"type":"function","title":"SFTPClient.Operations.OpenDir.open_dir!/3","doc":"Opens a handle to a directory on the server. The handle can be used for\nreading directory contents. Then runs the function and closes the handle when\nfinished. Raises when the operation fails.","ref":"SFTPClient.Operations.OpenDir.html#open_dir!/3"},{"type":"module","title":"SFTPClient.Operations.OpenFile","doc":"A module that provides functions to open a file on an SFTP server in  order to\nread their contents.","ref":"SFTPClient.Operations.OpenFile.html"},{"type":"function","title":"SFTPClient.Operations.OpenFile.open_file/3","doc":"Opens a file on the server and returns a handle, which can be used for reading\nor writing.","ref":"SFTPClient.Operations.OpenFile.html#open_file/3"},{"type":"function","title":"SFTPClient.Operations.OpenFile.open_file/4","doc":"Opens a file on the server and returns a handle, which can be used for reading\nor writing, then runs the function and closes the handle when finished.","ref":"SFTPClient.Operations.OpenFile.html#open_file/4"},{"type":"function","title":"SFTPClient.Operations.OpenFile.open_file!/3","doc":"Opens a file on the server and returns a handle, which can be used for reading\nor writing. Raises when the operation fails.","ref":"SFTPClient.Operations.OpenFile.html#open_file!/3"},{"type":"function","title":"SFTPClient.Operations.OpenFile.open_file!/4","doc":"Opens a file on the server and returns a handle, which can be used for reading\nor writing, then runs the function and closes the handle when finished. Raises\nwhen the operation fails.","ref":"SFTPClient.Operations.OpenFile.html#open_file!/4"},{"type":"module","title":"SFTPClient.Operations.ReadDir","doc":"A module that provides functions to read a list of directories on an SFTP\nserver from a given file handle.","ref":"SFTPClient.Operations.ReadDir.html"},{"type":"function","title":"SFTPClient.Operations.ReadDir.read_dir/1","doc":"Reads the directory contents from the server, and returns the data as String.","ref":"SFTPClient.Operations.ReadDir.html#read_dir/1"},{"type":"function","title":"SFTPClient.Operations.ReadDir.read_dir!/1","doc":"Reads a file from the server, and returns the data as String. Raises when the\noperation fails.","ref":"SFTPClient.Operations.ReadDir.html#read_dir!/1"},{"type":"module","title":"SFTPClient.Operations.ReadFile","doc":"A module that provides functions to read file contents from an SFTP server.","ref":"SFTPClient.Operations.ReadFile.html"},{"type":"function","title":"SFTPClient.Operations.ReadFile.read_file/2","doc":"Reads a file from the server, and returns the data as String.","ref":"SFTPClient.Operations.ReadFile.html#read_file/2"},{"type":"function","title":"SFTPClient.Operations.ReadFile.read_file!/2","doc":"Reads a file from the server, and returns the data as String. Raises when the\noperation fails.","ref":"SFTPClient.Operations.ReadFile.html#read_file!/2"},{"type":"module","title":"SFTPClient.Operations.ReadFileChunk","doc":"A module that provides functions to read chunks of data from a file on an SFTP\nserver.","ref":"SFTPClient.Operations.ReadFileChunk.html"},{"type":"function","title":"SFTPClient.Operations.ReadFileChunk.read_file_chunk/2","doc":"Reads the given number of bytes (length) from the file referenced by handle.\nIf the file is read past eof, only the remaining bytes are read and returned.\nIf no bytes are read, `:eof` is returned.","ref":"SFTPClient.Operations.ReadFileChunk.html#read_file_chunk/2"},{"type":"function","title":"SFTPClient.Operations.ReadFileChunk.read_file_chunk!/2","doc":"Reads the given number of bytes (length) from the file referenced by handle.\nIf the file is read past eof, only the remaining bytes are read and returned.\nIf no bytes are read, `:eof` is returned. Raises when the operation fails.","ref":"SFTPClient.Operations.ReadFileChunk.html#read_file_chunk!/2"},{"type":"module","title":"SFTPClient.Operations.ReadLink","doc":"A module that provides functions to retrieve the target of a symbolic link on\nan SFTP server.","ref":"SFTPClient.Operations.ReadLink.html"},{"type":"function","title":"SFTPClient.Operations.ReadLink.read_link/2","doc":"Reads the link target from the symbolic link specified by path.","ref":"SFTPClient.Operations.ReadLink.html#read_link/2"},{"type":"function","title":"SFTPClient.Operations.ReadLink.read_link!/2","doc":"Reads the link target from the symbolic link specified by path. Raises when\nthe operation fails.","ref":"SFTPClient.Operations.ReadLink.html#read_link!/2"},{"type":"module","title":"SFTPClient.Operations.Rename","doc":"A module that provides functions to rename files and directories on an SFTP\nserver.","ref":"SFTPClient.Operations.Rename.html"},{"type":"function","title":"SFTPClient.Operations.Rename.rename/3","doc":"Renames a file named `old_path` and gives it the name specified by `new_path`.","ref":"SFTPClient.Operations.Rename.html#rename/3"},{"type":"function","title":"SFTPClient.Operations.Rename.rename!/3","doc":"Renames a file named `old_path` and gives it the name specified by `new_path`.\nRaises when the operation fails.","ref":"SFTPClient.Operations.Rename.html#rename!/3"},{"type":"module","title":"SFTPClient.Operations.StreamFile","doc":"A module that provides functions to create streams from and to files on an\nSFTP server.","ref":"SFTPClient.Operations.StreamFile.html"},{"type":"function","title":"SFTPClient.Operations.StreamFile.stream_file/2","doc":"Creates a stream that allows reading from and writing to the server.","ref":"SFTPClient.Operations.StreamFile.html#stream_file/2"},{"type":"function","title":"SFTPClient.Operations.StreamFile.stream_file/3","doc":"Creates a stream that allows reading from and writing to the server using the\nspecified chunk size.","ref":"SFTPClient.Operations.StreamFile.html#stream_file/3"},{"type":"function","title":"SFTPClient.Operations.StreamFile.stream_file!/2","doc":"Creates a stream that allows reading from and writing to the server.","ref":"SFTPClient.Operations.StreamFile.html#stream_file!/2"},{"type":"function","title":"SFTPClient.Operations.StreamFile.stream_file!/3","doc":"Creates a stream that allows reading from and writing to the server using the\nspecified chunk size.","ref":"SFTPClient.Operations.StreamFile.html#stream_file!/3"},{"type":"module","title":"SFTPClient.Operations.WriteFile","doc":"A module that provides functions to write file contents to an SFTP server.","ref":"SFTPClient.Operations.WriteFile.html"},{"type":"function","title":"SFTPClient.Operations.WriteFile.write_file/3","doc":"Writes a file to the given path on the connected server.","ref":"SFTPClient.Operations.WriteFile.html#write_file/3"},{"type":"function","title":"SFTPClient.Operations.WriteFile.write_file!/3","doc":"Writes a file to the given path on the connected server. Raises when the\noperation fails.","ref":"SFTPClient.Operations.WriteFile.html#write_file!/3"},{"type":"module","title":"SFTPClient.Operations.WriteFileChunk","doc":"A module that provides functions to write chunks of data to a file on an SFTP\nserver.","ref":"SFTPClient.Operations.WriteFileChunk.html"},{"type":"function","title":"SFTPClient.Operations.WriteFileChunk.write_file_chunk/2","doc":"Writes data to the file referenced by handle. The file is to be opened with\nwrite or append flag.","ref":"SFTPClient.Operations.WriteFileChunk.html#write_file_chunk/2"},{"type":"function","title":"SFTPClient.Operations.WriteFileChunk.write_file_chunk!/2","doc":"Writes data to the file referenced by handle. The file is to be opened with\nwrite or append flag. Raises when the operation fails.","ref":"SFTPClient.Operations.WriteFileChunk.html#write_file_chunk!/2"},{"type":"exception","title":"SFTPClient.ConnError","doc":"An error that is raised when connection to the SFTP server failed.","ref":"SFTPClient.ConnError.html"},{"type":"type","title":"SFTPClient.ConnError.t/0","doc":"","ref":"SFTPClient.ConnError.html#t:t/0"},{"type":"exception","title":"SFTPClient.InvalidOptionError","doc":"An error that is raised when the configuration contains invalid options.","ref":"SFTPClient.InvalidOptionError.html"},{"type":"function","title":"SFTPClient.InvalidOptionError.message/1","doc":"","ref":"SFTPClient.InvalidOptionError.html#message/1"},{"type":"type","title":"SFTPClient.InvalidOptionError.t/0","doc":"","ref":"SFTPClient.InvalidOptionError.html#t:t/0"},{"type":"exception","title":"SFTPClient.OperationError","doc":"An error that is raised when an operation failed.","ref":"SFTPClient.OperationError.html"},{"type":"function","title":"SFTPClient.OperationError.message/1","doc":"","ref":"SFTPClient.OperationError.html#message/1"},{"type":"type","title":"SFTPClient.OperationError.t/0","doc":"","ref":"SFTPClient.OperationError.html#t:t/0"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2019 Tobias Casper\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# SFTP Client\n\n[![Build](https://github.com/tlux/sftp_client/actions/workflows/elixir.yml/badge.svg)](https://github.com/tlux/sftp_client/actions/workflows/elixir.yml)\n[![Coverage Status](https://coveralls.io/repos/github/tlux/sftp_client/badge.svg?branch=main)](https://coveralls.io/github/tlux/sftp_client?branch=main)\n[![Module Version](https://img.shields.io/hexpm/v/sftp_client.svg)](https://hex.pm/packages/sftp_client)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/sftp_client/)\n[![Total Download](https://img.shields.io/hexpm/dt/sftp_client.svg)](https://hex.pm/packages/sftp_client)\n[![License](https://img.shields.io/hexpm/l/sftp_client.svg)](https://github.com/tlux/sftp_client/blob/main/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/tlux/sftp_client.svg)](https://github.com/tlux/sftp_client/commits/main)\n\nAn Elixir SFTP Client that wraps Erlang's\n[ssh](http://erlang.org/doc/man/ssh.html) and\n[ssh_sftp](http://erlang.org/doc/man/ssh_sftp.html).","ref":"readme.html"},{"type":"extras","title":"Prerequisites - Overview","doc":"- Erlang 24 or greater\n- Elixir 1.11 or greater","ref":"readme.html#prerequisites"},{"type":"extras","title":"Installation - Overview","doc":"The package can be installed by adding `:sftp_client` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:sftp_client, \"~> 2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Overview","doc":"There are bang (!) counterparts for almost all available functions.\n\n#","ref":"readme.html#usage"},{"type":"extras","title":"Connect & Disconnect - Overview","doc":"To open a new connection to an SFTP server:\n\n```elixir\n{:ok, conn} = SFTPClient.connect(host: \"ftp.myhost.com\")\n```\n\nDue to a [change in OTP\n24](https://github.com/erlang/otp/commit/59285df73841273adb111996cdb590ae1b86742b)\nthat removed automatic public key lookup in the sftp module you may need to\ndefine the `modify_algorithms` option to avoid \"Key exchange failed\" errors:\n\n```elixir\n{:ok, conn} = SFTPClient.connect(\n  host: \"ftp.myhost.com\",\n  modify_algorithms: [\n    append: [\n      public_key: [:\"ssh-rsa\"]\n    ]\n  ]\n)\n```\n\nRefer to the docs for `SFTPClient.Operations.Connect.connect/1` to find out\nall available options.\n\nIt is strongly recommended to close a connection after your operations have\ncompleted:\n\n```elixir\nSFTPClient.disconnect(conn)\n```\n\nFor short-lived connections you can also use a function as second argument.\nAfter the function body has run or raises, the connection is automatically\nclosed.\n\n```elixir\nSFTPClient.connect([host: \"ftp.myhost.com\"], fn conn ->\n  # Do something with conn\nend)\n```\n\n#","ref":"readme.html#connect-disconnect"},{"type":"extras","title":"Download - Overview","doc":"To download a file from the server you can use the following function.\n\n```elixir\nSFTPClient.download_file(conn, \"my/remote/dir/file.jpg\", \"my/dir/local-file.jpg\")\n# => {:ok, \"my/dir/local-file.jpg\"}\n```\n\nWhen the third argument is an existing directory on your file system, the file\nis downloaded to a file with the same name as the one on the server.\n\n```elixir\nSFTPClient.download_file(conn, \"my/remote/dir/image.png\", \"my/local/dir\")\n# => {:ok, \"my/local/dir/image.png\"}\n```\n\nIt is also possible to use Streams to download data into a file or memory.\n\n```elixir\nsource_stream = SFTPClient.stream_file!(conn, \"my/remote/file.jpg\")\ntarget_stream = File.stream!(\"my/local/file.jpg\")\n\nsource_stream\n|> Stream.into(target_stream)\n|> Stream.run()\n```\n\n#","ref":"readme.html#download"},{"type":"extras","title":"Upload - Overview","doc":"To upload are file from the file system you can use the following function.\n\n```elixir\nSFTPClient.upload_file(conn, \"my/local/dir/file.jpg\", \"my/remote/dir/file.jpg\")\n# => {:ok, \"my/remote/dir/file.jpg\"}\n```\n\nYou can also use Streams to upload data. Please make sure to set a proper chunk\nsize or the upload may be very slow.\n\n```elixir\nsource_stream = File.stream!(\"my/local/file.jpg\", [], 32_768)\ntarget_stream = SFTPClient.stream_file!(conn, \"my/remote/file.jpg\")\n\nsource_stream\n|> Stream.into(target_stream)\n|> Stream.run()\n```\n\n#","ref":"readme.html#upload"},{"type":"extras","title":"List Directory - Overview","doc":"```elixir\nSFTPClient.list_dir(conn, \"my/dir\")\n# => {:ok, [\"my/dir/file_1.jpg\", \"my/dir/file_2.jpg\", ...]}\n```\n\n#","ref":"readme.html#list-directory"},{"type":"extras","title":"Create Directory - Overview","doc":"```elixir\nSFTPClient.make_dir(conn, \"my/new/dir\")\n```\n\nNote that this operation fails unless the parent directory exists.\n\n#","ref":"readme.html#create-directory"},{"type":"extras","title":"Delete - Overview","doc":"To delete a file:\n\n```elixir\nSFTPClient.delete_file(conn, \"my/remote/file.jpg\")\n```\n\nTo delete a directory:\n\n```elixir\nSFTPClient.delete_dir(conn, \"my/remote/dir\")\n```\n\nNote that a directory cannot be deleted as long as it still contains files.\n\n#","ref":"readme.html#delete"},{"type":"extras","title":"Rename - Overview","doc":"To move/rename a file or directory:\n\n```elixir\nSFTPClient.rename(conn, \"my/remote/file.jpg\", \"my/remote/new-file.jpg\")\n```\n\n#","ref":"readme.html#rename"},{"type":"extras","title":"File Info - Overview","doc":"You can retrieve meta data about a file from the server such as file size,\nmodification time, file permissions, owner and so on.\n\n```elixir\nSFTPClient.file_info(conn, \"my/remote/file.jpg\")\n# => {:ok, %File.Stat{...}}\n```\n\nRefer to the [`File.Stat`](https://hexdocs.pm/elixir/File.Stat.html) docs for a\nlist of available file information.\n\n#","ref":"readme.html#file-info"},{"type":"extras","title":"Symbolic Links - Overview","doc":"There are also a couple of functions that handle symlinks.\n\nIt is possible to get the target of a symlink.\n\n```elixir\nSFTPClient.read_link(conn, \"my/remote/link.jpg\")\n# => {:ok, \"my/remote/file.jpg\"}\n```\n\nYou can retrieve meta data about symlinks, similar to `file_info/2`.\n\n```elixir\nSFTPClient.link_info(conn, \"my/remote/link.jpg\")\n# => {:ok, %File.Stat{...}}\n```\n\nAnd you are able to create symlinks.\n\n```elixir\nSFTPClient.make_link(conn, \"my/remote/link.jpg\", \"my/remote/file.jpg\")\n```","ref":"readme.html#symbolic-links"},{"type":"extras","title":"License - Overview","doc":"This library is released under the MIT License. See the [LICENSE.md](./LICENSE.md) file\nfor further details.","ref":"readme.html#license"}],"content_type":"text/markdown"}